<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace local_rwth_sd_sync\output;

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot.'/local/rwth_sd_sync/externallib.php');

use stdClass;

use context_course;
use html_writer;

use local_rwth_sd_sync\capability_helper;
use local_rwth_sd_sync_external;

/**
 * IMPORTANT: This class needs to be used by a theme, otherwise it won't affect
 *            the rendering of calendar views.
 */
class core_calendar_renderer extends \core_calendar_renderer {

    public function render_from_template($originalname, $context) {
        $name = $this->template_name_override($originalname);
        $context = $this->template_arguments_override($originalname, $context);
        return parent::render_from_template($name, $context);
    }

    private function template_name_override($originalname) {
        switch ($originalname) {
            case 'core_calendar/calendar_month':
                return 'local_rwth_sd_sync/calendar_month';
            case 'core_calendar/calendar_day':
                return 'local_rwth_sd_sync/calendar_day';
            case 'core_calendar/month_detailed':
                return 'local_rwth_sd_sync/month_detailed';
            case 'core_calendar/day_detailed':
                return 'local_rwth_sd_sync/day_detailed';
        }
        return $originalname;
    }

    private function template_arguments_override($originalname, $args) {
        switch ($originalname) {
            case 'core_calendar/calendar_threemonth':
                foreach ((array)$args as $month) {
                    $this->calendar_month_override($month);
                }
                break;
            case 'core_calendar/calendar_month':
                $this->calendar_month_override($args);
                break;
            case 'core_calendar/calendar_day':
                $this->calendar_day_override($args);
                break;
            case 'core_calendar/month_detailed':
                $this->calendar_month_override($args);
                break;
            case 'core_calendar/day_detailed':
                $this->calendar_day_override($args);
                break;
        }
        return $args;
    }

    private function calendar_month_override($month) {
        foreach ($month->weeks as $week) {
            foreach ($week->days as $day) {
                $this->calendar_day_override($day);
            }
        }
    }

    private function calendar_day_override($day) {
        global $DB;
        foreach ($day->events as $event) {
            $event->title = html_entity_decode($event->name);
            $isrwthonlineevent = $DB->record_exists('rwth_sd_sync_appointment', ['moodle_eventid' => $event->id, 'eventsource' => 'rwthonline']);
            if (!$isrwthonlineevent) {
                continue;
            }

            $context = context_course::instance($event->course->id);
            if (has_capability('moodle/calendar:manageentries', $context)) {
                // Add some parameters needed by our templates.
                $event->isrwthonlineevent = $isrwthonlineevent;
                if ($isrwthonlineevent) {
                    $event->rwthonlineurl = local_rwth_sd_sync_external::get_rwthonline_event_url($event->id);
                }
                $event->text = get_string('rwthonline_event_help', 'local_rwth_sd_sync');

                // Make event not editable/deletable.
                $event->canedit = false;
                $event->candelete = false;
            }
        }
    }
}
